@@ -13,12 +13,12 @@ use std::{
 
 use crate::util::{poll, Polling};
 
-/// Castes all given ranges to `f64` values and calls `grid_search`.
+/// Castes all given ranges to `f64` values and calls [`grid_search()`].
 /// ```
 /// use std::{sync::Arc,time::Duration};
-/// use simple_optimization::{grid_search_m, Polling};
+/// use simple_optimization::{grid_search, Polling};
 /// fn simple_function(list: &[f64; 3], _: Option<Arc<()>>) -> f64 { list.iter().sum() }
-/// let best = grid_search_m!(
+/// let best = grid_search!(
 ///     (0f64..10f64, 5u32..15u32, 10i16..20i16), // Value ranges.
 ///     simple_function, // Evaluation function.
 ///     None, //  No additional evaluation data.
@@ -33,7 +33,7 @@ use crate::util::{poll, Polling};
 /// ```
 /// Due to specific design the `threads` parameter is excluded for now.
 #[macro_export]
-macro_rules! grid_search_m {
+macro_rules! grid_search {
     (
         // Generic
         ($($x:expr),*),
@@ -158,11 +158,11 @@ pub fn grid_search<
         evaluation_data: Option<Arc<A>>,
         polling: Option<Polling>,
         // Specifics
-        point_values: &Vec<Vec<T>>,
+        point_values: &Vec<Vec<T>>, // Ignore clippy, this needs to be `&Vec<Vec<T>>` to prevent borrow checker issue.
         mut point: [T; N],
     ) -> (f64, [T; N]) {
         // Could just `assert!(N>0)` and not handle it, but this handles it fine.
-        if 0 == point_values.len() {
+        if point_values.is_empty() {
             return (f(&point, evaluation_data), point);
         }
 
@@ -232,18 +232,18 @@ pub fn grid_search<
             );
         }
 
-        let joins: Vec<_> = handles.into_iter().map(|h| h.join().unwrap()).collect();
-        let (value, params) =
-            joins
-                .into_iter()
-                .fold((f64::MAX, [Default::default(); N]), |(bv, bp), (v, p)| {
-                    if v < bv {
-                        (v, p)
-                    } else {
-                        (bv, bp)
-                    }
-                });
-        return (value, params);
+        // Joins each handle folding across extracting the best value and best points.
+        let (value, params) = handles.into_iter().map(|h| h.join().unwrap()).fold(
+            (f64::MAX, [Default::default(); N]),
+            |(bv, bp), (v, p)| {
+                if v < bv {
+                    (v, p)
+                } else {
+                    (bv, bp)
+                }
+            },
+        );
+        (value, params)
     }
     fn search<
         A: 'static + Send + Sync,
@@ -261,7 +261,7 @@ pub fn grid_search<
         const N: usize,
     >(
         // Generics
-        point_values: &Vec<Vec<T>>,
+        point_values: &[Vec<T>],
         f: fn(&[T; N], Option<Arc<A>>) -> f64,
         evaluation_data: Option<Arc<A>>,
         counter: Arc<AtomicU64>,
@@ -304,6 +304,6 @@ pub fn grid_search<
                 break;
             }
         }
-        return (best_value, best_params);
+        (best_value, best_params)
     }
 }
