@@ -13,25 +13,24 @@ use std::{
 
 use crate::util::{poll, update_execution_position, Polling};
 
-
-/// Castes all given ranges to `f64` values and calls `random_search`.
+/// Castes all given ranges to `f64` values and calls [`random_search()`].
 /// ```
 /// use std::sync::Arc;
-/// use simple_optimization::{random_search_m, Polling};
+/// use simple_optimization::{random_search, Polling};
 /// fn simple_function(list: &[f64; 3], _: Option<Arc::<()>>) -> f64 { list.iter().sum() }
-/// let best = random_search_m!(
+/// let best = random_search!(
 ///     (0f64..10f64, 5u32..15u32, 10i16..20i16), // Value ranges.
 ///     simple_function, // Evaluation function.
 ///     None, // No additional evaluation data.
 ///     // By using `new` this defaults to polling every `10ms`, we also print progress `true` and exit early if `19.` or less is reached.
 ///     Some(Polling::new(true,Some(19.))),
-///     None,
+///     None, // Don't specify the number of threads.
 ///     1000, // Take `1000` samples (split between threads, so each thread only takes `1000/n` samples).
 /// );
 /// assert!(simple_function(&best, None) < 19.);
 /// ```
 #[macro_export]
-macro_rules! random_search_m {
+macro_rules! random_search {
     (
         // Generic
         ($($x:expr),*),
@@ -74,7 +73,7 @@ macro_rules! random_search_m {
 ///     None, // No additional evaluation data.
 ///     // By using `new` this defaults to polling every `10ms`, we also print progress `true` and exit early if `19.` or less is reached.
 ///     Some(Polling::new(true,Some(19.))),
-///     None,
+///     None, // Don't specify the number of threads.
 ///     1000, // Take `1000` samples (split between threads, so each thread only takes `1000/n` samples).
 /// );
 /// assert!(simple_function(&best, None) < 19.);
@@ -94,15 +93,8 @@ pub fn random_search<
     iterations: u64,
 ) -> [T; N] {
     // Gets cpu data
-    let cpus = if let Some(given_threads) = threads {
-        assert!(
-            given_threads >= 2,
-            "Due to fundamentally multi-threaded design, need at least 2 threads"
-        );
-        given_threads as u64
-    } else {
-        num_cpus::get() as u64
-    };
+    let cpus = crate::cpus!(threads);
+
     let search_cpus = cpus - 1; // 1 cpu is used for polling, this one.
 
     let remainder = iterations % search_cpus;
@@ -194,17 +186,17 @@ pub fn random_search<
         );
     }
 
-    let joins: Vec<_> = handles.into_iter().map(|h| h.join().unwrap()).collect();
-
-    let (_, best_params) = joins
-        .into_iter()
-        .fold((best_value, best_params), |(bv, bp), (v, p)| {
+    // Joins all handles and folds across extracting the best value and best points.
+    let (_, best_params) = handles.into_iter().map(|h| h.join().unwrap()).fold(
+        (best_value, best_params),
+        |(bv, bp), (v, p)| {
             if v < bv {
                 (v, p)
             } else {
                 (bv, bp)
             }
-        });
+        },
+    );
 
     return best_params;
 
@@ -288,6 +280,6 @@ pub fn random_search<
         // Update execution position
         // 0 represents ended state
         thread_execution_position.store(0, Ordering::SeqCst);
-        return (best_value, best_params);
+        (best_value, best_params)
     }
 }
